// ==================================================
// 1. TARJETAS DEL JUEGO (SECCIÓN DE JUEGO DE CARTAS)
// ==================================================
document.addEventListener("DOMContentLoaded", () => {
  // Definición de las tarjetas del juego
  const tarjetas = [
    { texto: "Usar mayúsculas para enfatizar un mensaje.", correcta: false },
    { texto: "Responder siempre con respeto y empatía.", correcta: true },
    { texto: "Citar fuentes al compartir contenido ajeno.", correcta: true },
    { texto: "Enviar mensajes sin revisar la ortografía.", correcta: false },
    { texto: "Evitar discusiones ofensivas en foros.", correcta: true },
    { texto: "Compartir información privada de otras personas.", correcta: false }
  ];

  const contenedorTarjetas = document.getElementById("tarjetas");

  // Creación de cada tarjeta y asignación de evento de clic para alternar la selección
  tarjetas.forEach((tarjeta) => {
    const div = document.createElement("div");
    div.className = "tarjeta";
    div.textContent = tarjeta.texto;
    div.dataset.correcta = tarjeta.correcta;

    div.addEventListener("click", () => {
      div.classList.toggle("seleccionada");
    });

    contenedorTarjetas.appendChild(div);
  });

  // Verificación de respuestas (opcional)
  document.getElementById("verificar").addEventListener("click", () => {
    const seleccionadas = document.querySelectorAll(".tarjeta.seleccionada");
    let correctas = 0;
    let incorrectas = 0;

    seleccionadas.forEach(tarjeta => {
      if (tarjeta.dataset.correcta === "true") {
        correctas++;
      } else {
        incorrectas++;
      }
    });

    const totalCorrectas = tarjetas.filter(t => t.correcta).length;
    const mensajeJuego = document.getElementById("mensaje-juego");

    if (correctas === totalCorrectas && incorrectas === 0) {
      mensajeJuego.textContent = "¡Perfecto! Identificaste todas las buenas prácticas correctamente.";
      mensajeJuego.style.color = "green";
    } else {
      mensajeJuego.textContent = `Respuestas correctas: ${correctas}. Respuestas incorrectas: ${incorrectas}.`;
      mensajeJuego.style.color = "red";
    }
  });
});

// ==================================================
// 2. MANEJO DE LAS PESTAÑAS PRINCIPAL
// ==================================================
document.addEventListener("DOMContentLoaded", () => {
  const tabs = document.querySelectorAll(".tab");
  const contents = document.querySelectorAll(".tab-content");

  function showTab(index) {
    tabs.forEach(t => t.classList.remove("active"));
    contents.forEach(c => c.classList.remove("active"));

    tabs[index].classList.add("active");
    contents[index].classList.add("active");
  }

  // Asignar evento de clic a cada pestaña
  tabs.forEach((tab, index) => {
    tab.addEventListener("click", () => showTab(index));
  });

  // Mostrar la pestaña "Introducción" por defecto (asumiendo que es la primera)
  showTab(0);

  // ==================================================
  // 2.1. MODAL DE BIENVENIDA
  // ==================================================
  const modal = document.getElementById("modal-bienvenida");
  const cerrarModal = document.getElementById("cerrar-modal");

  modal.style.display = "flex";

  cerrarModal.addEventListener("click", () => {
    modal.classList.add("hidden");
    setTimeout(() => modal.remove(), 500);
  });
});

// ==================================================
// 3. MANEJO DEL SUBMENÚ DE PESTAÑAS (CONTENIDO INTERNO)
// ==================================================
document.addEventListener("DOMContentLoaded", () => {
  const subTabs = document.querySelectorAll(".sub-tab");
  const subTabContents = document.querySelectorAll(".sub-tab-content");

  function showSubTab(subTabId) {
    // Quitar clase 'active' de todos los sub-tabs y sus contenidos
    subTabs.forEach(tab => tab.classList.remove("active"));
    subTabContents.forEach(content => content.classList.remove("active"));

    // Activar el sub-tab y su contenido correspondiente
    document.querySelector(`[data-subtab="${subTabId}"]`).classList.add("active");
    document.getElementById(subTabId).classList.add("active");
  }

  // Asignar eventos de clic a cada sub-tab
  subTabs.forEach(tab => {
    tab.addEventListener("click", () => {
      const subTabId = tab.getAttribute("data-subtab");
      showSubTab(subTabId);
    });
  });

  // Mostrar por defecto el primer subtema (por ejemplo, "subtema1")
  showSubTab("subtema1");
});

// ==================================================
// 4. MANEJO DE LOS OBJETIVOS (EXPANSIÓN Y CONTRACCIÓN)
// ==================================================
function toggleObjetivo(element) {
  const allObjetivos = document.querySelectorAll('.objetivo');
  allObjetivos.forEach(obj => {
    if (obj !== element) {
      obj.classList.remove('active');
    }
  });
  element.classList.toggle('active');
}

// ==================================================
// 5. MANEJO DE LAS ACTIVIDADES: JUEGO DE CARTAS Y ACTIVIDAD H5P
// ==================================================
document.addEventListener("DOMContentLoaded", () => {
  // Referencias a las tarjetas de selección
  const cardCartas = document.getElementById("card-cartas");
  const cardH5p = document.getElementById("card-h5p");

  // Contenedores de selección y actividades
  const seleccionActividades = document.getElementById("seleccion-actividades");
  const actividadCartas = document.getElementById("actividad-cartas");
  const actividadH5p = document.getElementById("h5p-placeholder");

  // Botones de regreso
  const backCartas = document.getElementById("back-cartas");
  const backH5p = document.getElementById("back-h5p");

  // Mostrar actividad de Juego de Cartas al hacer clic en la tarjeta correspondiente
  cardCartas.addEventListener("click", () => {
    seleccionActividades.style.display = "none";
    actividadCartas.style.display = "block";
  });

  // Mostrar actividad H5P al hacer clic en la tarjeta correspondiente
  cardH5p.addEventListener("click", () => {
    seleccionActividades.style.display = "none";
    actividadH5p.style.display = "block";
    loadH5p();
  });

  // Regresar a la pantalla de selección desde la actividad de Juego de Cartas
  backCartas.addEventListener("click", () => {
    actividadCartas.style.display = "none";
    seleccionActividades.style.display = "flex";  // Ajusta según el diseño: "flex" o "block"
  });

  // Regresar a la pantalla de selección desde la actividad H5P
  backH5p.addEventListener("click", () => {
    actividadH5p.style.display = "none";
    seleccionActividades.style.display = "flex";
  });

  // Función para cargar el contenido H5P (solo se carga una vez)
  function loadH5p() {
    if (actividadH5p.getAttribute("data-loaded") === "true") return;

    const iframe = document.createElement("iframe");
    iframe.src = "https://espocheva.h5p.com/content/1292502425754436648/embed";
    iframe.setAttribute("aria-label", "La Netiqueta OA");
    iframe.width = "1088";
    iframe.height = "637";
    iframe.frameBorder = "0";
    iframe.allowFullscreen = true;
    iframe.allow = "autoplay *; geolocation *; microphone *; camera *; midi *; encrypted-media *";

    // Limpiar el contenedor y reinserta el botón de regreso antes del iframe
    actividadH5p.innerHTML = "";
    actividadH5p.appendChild(backH5p);
    actividadH5p.appendChild(iframe);
    actividadH5p.setAttribute("data-loaded", "true");

    // Agregar script del resizer de H5P
    const script = document.createElement("script");
    script.src = "https://espocheva.h5p.com/js/h5p-resizer.js";
    script.charset = "UTF-8";
    document.body.appendChild(script);
  }
});

// ==================================================
// 6. AUTOEVALUACIÓN (CUESTIONARIO)
// ==================================================
const correctAnswers = {
  q1: "a",
  q2: "Falso",
  q3: "ser humano",
  q4: "c",
  q5: "Falso",
  q6: "b",
  q7: "fuentes",
  q8: "b",
  q9: "Falso",
  q10: "b"
};

const feedbackMessages = {
  q1: "La Netiqueta son las normas de comportamiento en entornos digitales, fundamentales para interactuar respetuosamente.",
  q2: "Escribir en mayúsculas equivale a 'gritar' en comunicación digital y puede ser considerado descortés.",
  q3: "Es importante tratar a las personas en línea con el mismo respeto que en interacciones cara a cara.",
  q4: "Los mensajes deben tener un tono respetuoso, incluso en situaciones difíciles.",
  q5: "Respetar la privacidad es un principio básico de la Netiqueta; nunca comparta información sin consentimiento.",
  q6: "Las discusiones tóxicas no contribuyen al diálogo constructivo y dañan la interacción en línea.",
  q7: "Citar fuentes es esencial para evitar el plagio y respetar los derechos de autor.",
  q8: "El spam es molesto y desperdicia el tiempo y los recursos de quienes reciben los mensajes.",
  q9: "En contextos académicos y profesionales se debe usar un lenguaje formal para mantener el respeto.",
  q10: "Compartir conocimientos enriquece a las comunidades digitales y fomenta el aprendizaje colectivo."
};

document.getElementById("quiz-form").addEventListener("submit", function(e) {
  e.preventDefault();
  const total = 10;
  let score = 0;
  let wrongDetails = [];
  const formData = new FormData(this);

  for (let q in correctAnswers) {
    let userAnswer = formData.get(q);
    if (q === "q3" || q === "q7") {
      userAnswer = userAnswer.trim().toLowerCase();
    }
    const correct = correctAnswers[q].toLowerCase();
    if (userAnswer === correct) {
      score++;
    } else {
      wrongDetails.push({
        questionNumber: q.substring(1),
        userAnswer: userAnswer,
        correctAnswer: correctAnswers[q],
        feedback: feedbackMessages[q]
      });
    }
  }

  document.getElementById("score-text").textContent =
    `Obtuviste ${score} de ${total} respuestas correctas. Errores: ${total - score}.`;

  const feedbackListDiv = document.getElementById("feedback-list");
  feedbackListDiv.innerHTML = "";
  if (wrongDetails.length > 0) {
    wrongDetails.forEach(detail => {
      const div = document.createElement("div");
      div.classList.add("feedback-item");
      div.innerHTML = `<strong>Pregunta ${detail.questionNumber}:</strong><br>
                       Tu respuesta: ${detail.userAnswer}<br>
                       Respuesta correcta: ${detail.correctAnswer}<br>
                       Retroalimentación: ${detail.feedback}<br>`;
      feedbackListDiv.appendChild(div);
    });
  } else {
    feedbackListDiv.innerHTML = "<p>¡Excelente! Todas las respuestas son correctas.</p>";
  }

  document.getElementById("quiz-form").style.display = "none";
  document.getElementById("results").style.display = "block";
});

document.getElementById("restart-btn").addEventListener("click", function() {
  document.getElementById("quiz-form").reset();
  document.getElementById("quiz-form").style.display = "block";
  document.getElementById("results").style.display = "none";
});
document.addEventListener("DOMContentLoaded", () => {
  // --------------------------------------------------
  // Variables y referencias para la actividad Drag & Drop
  // --------------------------------------------------
  const cardDragDrop = document.getElementById("card-dragdrop");
  const actividadDragDrop = document.getElementById("actividad-dragdrop");
  const backDragDrop = document.getElementById("back-dragdrop");
  const checkBtn = document.getElementById("checkBtn");
  const restartBtn = document.getElementById("restartBtn");
  const feedback = document.getElementById("feedback");

  // Definir mapeo de respuestas correctas:
  // - "item1" debe estar en la dropzone con id "dropzone1" (Buenas Prácticas)
  // - "item2" debe estar en la dropzone con id "dropzone2" (Malas Prácticas)
  const correctMapping = {
    "item1": "dropzone1",
    "item2": "dropzone2",
    "item3": "dropzone1",
    "item4": "dropzone2",
    "item5": "dropzone2",
    "item6": "dropzone2"
  };

  // --------------------------------------------------
  // Mostrar la actividad Drag & Drop cuando se hace clic en la tarjeta
  // --------------------------------------------------
  cardDragDrop.addEventListener("click", () => {
    document.getElementById("seleccion-actividades").style.display = "none";
    actividadDragDrop.style.display = "block";
  });

  // Botón de regreso: Oculta la actividad y vuelve a la selección
  backDragDrop.addEventListener("click", () => {
    actividadDragDrop.style.display = "none";
    document.getElementById("seleccion-actividades").style.display = "flex";
    resetDragDrop();
  });

  // Botón de reinicio: Reinicia la actividad (aquí se opta por recargar la página)
  restartBtn.addEventListener("click", () => {
    resetDragDrop();
  });

  // --------------------------------------------------
  // Configurar eventos de arrastre para los elementos draggables
  // --------------------------------------------------
  const draggables = document.querySelectorAll("#actividad-dragdrop .draggable");
  const dropzones = document.querySelectorAll("#actividad-dragdrop .dropzone-area");

  draggables.forEach(item => {
    item.addEventListener("dragstart", dragStart);
    item.addEventListener("dragend", dragEnd);
  });

  dropzones.forEach(zone => {
    zone.addEventListener("dragover", dragOver);
    zone.addEventListener("drop", drop);
  });

  function dragStart(e) {
    e.dataTransfer.setData("text/plain", e.target.id);
    setTimeout(() => {
      e.target.style.opacity = "0.5";
    }, 0);
  }

  function dragEnd(e) {
    e.target.style.opacity = "1";
  }

  function dragOver(e) {
    e.preventDefault();
  }

  function drop(e) {
    e.preventDefault();
    const id = e.dataTransfer.getData("text/plain");
    const draggableElement = document.getElementById(id);
    // Mueve el elemento a la dropzone en la que se soltó
    e.currentTarget.appendChild(draggableElement);
    // Limpiar cualquier feedback anterior
    feedback.textContent = "";
  }

  // --------------------------------------------------
  // Botón para comprobar respuestas
  // --------------------------------------------------
  checkBtn.addEventListener("click", () => {
    let total = Object.keys(correctMapping).length;
    let correctCount = 0;

    draggables.forEach(item => {
      // Obtener el id del contenedor donde está el ítem
      const parentId = item.parentElement.id;
      if (correctMapping[item.id] === parentId) {
        correctCount++;
      }
    });

    if (correctCount === total) {
      feedback.textContent = "¡Excelente! Todas las respuestas son correctas.";
      feedback.style.color = "green";
      // Efecto de confeti (usando canvas-confetti)
      confetti({
        particleCount: 100,
        spread: 70,
        origin: { y: 0.6 }
      });
    } else {
      feedback.textContent = `Aciertos: ${correctCount} de ${total}.`;
      feedback.style.color = "red";
    }
  });

  // --------------------------------------------------
  // Función para reiniciar la actividad Drag & Drop
  // --------------------------------------------------
  function resetDragDrop() {
    // Mover todos los elementos draggables a su contenedor original (#draggables)
    const containerOriginal = document.getElementById("draggables");
    draggables.forEach(item => {
      containerOriginal.appendChild(item);
      item.style.opacity = "1";
    });
    feedback.textContent = "";
  }
});
document.addEventListener("DOMContentLoaded", () => {
  // Referencias a los elementos del juego
  const cardWordwall = document.getElementById("card-wordwall");
  const actividadWordwall = document.getElementById("actividad-wordwall");
  const seleccionActividades = document.getElementById("seleccion-actividades");
  const backWordwall = document.getElementById("back-wordwall");
  const wordwallContainer = document.querySelector(".wordwall-container");

  // Evento al hacer clic en la tarjeta de Wordwall
  cardWordwall.addEventListener("click", () => {
      seleccionActividades.style.display = "none";
      actividadWordwall.style.display = "block";

      // Verificar si ya se cargó el iframe
      if (!wordwallContainer.querySelector("iframe")) {
          // Crear el iframe de Wordwall
          const iframe = document.createElement("iframe");
          iframe.src = "https://wordwall.net/es/embed/60b112452590409fb44b31937a442191?themeId=59&templateId=69&fontStackId=0";
          iframe.width = "8000";
          iframe.height = "450";
          iframe.frameBorder = "0";
          iframe.allowFullscreen = true;

          // Limpiar el contenedor antes de agregar el iframe
          wordwallContainer.innerHTML = "";
          wordwallContainer.appendChild(iframe);
      }
  });

  // Evento para volver a la selección de actividades
  backWordwall.addEventListener("click", () => {
      actividadWordwall.style.display = "none";
      seleccionActividades.style.display = "flex";
  });
});
